Gene List

Phenotypic metrics
i
Phenotype severity is not displayed when phenotype evaluation is binary (presence/absence).
Phenotypes similarity: 1 - 100
Biological annotations
Genotype
Homo
Hetero
Hemi
Sex
Female
Male
Life stage
i
Early: -16w, Interval: 17-48w, Late: 49w-
Embryo
Early
Interval
Late

Similarity of accessory phenotypes

Markup
Highlight
i
Human Disease annotations use IMPC Disease Models
Human Disease

Search

Layout & Display
Layout:
Font size: 20
Edge width: 5
Node repulsion: 5
Export
i
GraphML can be used to visualize with desktop version of Cytoscape.
Documentation Contact